==> soda-0.0.2.tgz: 1289345747859-0.8150089313276112/test.js <==

var soda = require('./index')
  , assert = require('assert');

var browser = soda.createClient({
    'url': 'http://rafael:delaghetto@sirrobertborden.ca.demo.learnboost.com'
  , 'username': 'tjholowaychuk'
  , 'access-key': 'ba3fc050-2b4e-45cf-b214-ba0b4f2503e1'
  , 'os': 'Linux'
  , 'browser': 'firefox'
  , 'browser-version': '3.5.'
  , 'job-name': 'Add Class Schedule'
  , 'max-duration': 300 // 5 minutes
});

// Log commands as they are fired
browser.on('command', function(cmd, args){
  console.log(' \x1b[33m%s\x1b[0m: %s', cmd, args.join(', '));
});

soda.prototype.login = function(user, pass){
    return this
      .chain
      .session()
      .setTimeout(8000)
      .open('/')
      .waitForElementPresent('password')
      .type('username', user)
      .type('password', pass)
      .clickAndWait('//input[@value="Submit"]');
};

soda.prototype.assertSuccessMessage = function(str) {
  return this.assertText('css=.success-msgs li:nth-child(1)', str);
};

soda.prototype.waitForDialog = function() {
  return this.waitForElementPresent('css=.dialog');
};

var now = new Date;
var days = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];

browser
  .chain
  .session()
  .setTimeout(8000)
  .open('/')
  .setSpeed(500)
  .waitForElementPresent('css=.signup-msg')
  // Sign up
  .clickAndWait('css=.signup-msg a')
  // Activated step
  .assertText('css=div.active', 'Enter your information')
  // Signing up for school
  .assertText('css=.school-overview strong', 'Sir Robert Borden')
  // Fill in the form
  .type('user[first_name]', 'Tobi')
  .type('user[last_name]', 'Holowaychuk')
  .type('user[email]', 'tobi@learnboost.com')
  .type('user[password]', 'learnboost1')
  .type('user[password-repeat]', 'invalid')
  // Invalid password save attempt
  .click('send-link')
  .waitForElementPresent('css=label[for=user_password_repeat]')
  .assertText('css=label[for=user_password_repeat]', 'Make sure passwords match!')
  // Fix the password
  .type('user[password-repeat]', 'learnboost1')
  .clickAndWait('send-link')
  .testComplete()
  .end(function(err){
    if (err) throw err;
    console.log('done');
  })

==> soda-0.1.0.tgz: 1289345748250-0.47540075378492475/test.js <==

var soda = require('./index')
  , assert = require('assert');

var browser = soda.createClient({
  'url': 'https://rafael:delaghetto@demo.learnboost.com/'
//    'url': 'https://demo.learnboost.com/'
//    'url': 'http://rafael:delaghetto@lb.localhost'
  , 'username': 'tjholowaychuk'
  , 'access-key': 'ba3fc050-2b4e-45cf-b214-ba0b4f2503e1'
  , 'os': 'Linux'
  , 'browser': 'firefox'
  , 'browser-version': '3.5.'
  , 'job-name': 'Add Class Schedule'
  , 'max-duration': 300 // 5 minutes
});

// Log commands as they are fired
browser.on('command', function(cmd, args){
  console.log(' \x1b[33m%s\x1b[0m: %s', cmd, args.join(', '));
});

soda.prototype.login = function(user, pass){
    return this
      .chain
      .authenticate('rafael', 'delaghetto')
      .session()
      .setTimeout(8000)
      .open('/ca/sirrobertborden')
      .waitForElementPresent('password')
      .type('username', user)
      .type('password', pass)
      .clickAndWait('//input[@value="Submit"]');
};

soda.prototype.assertSuccessMessage = function(str) {
  return this.assertText('css=.success-msgs li:nth-child(1)', str);
};

soda.prototype.waitForDialog = function() {
  return this.waitForElementPresent('css=.dialog');
};

var now = new Date;
var days = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];

var user = {
    first: 'TJ'
  , last: 'Holowaychuk' 
  , email: 'tj@learnboost.com' 
};

browser
  .chain
  .session()
  .setTimeout(8000)
  .setSpeed(400)
  .open('/signup')
  // Find school
  .waitForElementPresent('name')
  .assertText('css=div.active', 'Find your school')
  .type('name', 'Sir Robert')
  .click('premium-input_search')
  .waitForElementPresent('css=#school-container .first')
  .assertText('css=#school-container .first strong', 'Sir Robert')
  .click('css=#school-container ul li:first-child')
  .waitForElementPresent('school-selected')
  .assertText('css=#school-selected .school-title', 'Sir Robert Borden')
  .assertText('css=#school-selected .school-data p:first-child', '2837 Centro St')
  .clickAndWait('link=Join')
  // Sign up
  .assertText('css=div.active', 'Enter your information')
  // Signing up for school
  .assertText('css=.school-overview strong', 'Sir Robert Borden')
  // Fill in the form
  .type('user[first_name]', 'TJs')
  .type('user[last_name]', 'Holowaychuk')
  .type('user[email]', 'tjs@learnboostsdfsd.com')
  .type('user[password]', 'learnboost1')
  .type('user[password-repeat]', 'invalid')
  // Invalid password save attempt
  .click('send-link')
  .waitForElementPresent('css=label[for=user_password_repeat]')
  .assertText('css=label[for=user_password_repeat]', 'Make sure passwords match!')
  // Fix the password
  .type('user[password-repeat]', 'learnboost1')
  .clickAndWait('send-link')
  // Redirects to "My classes" page
  .assertText('css=#classroom-table-content .msg', 'Sorry, no classrooms to show! Add one now.')
  .testComplete()
  .end(function(err){
    if (err) throw err;
    console.log('done');
  })
